@@ -9,7 +9,7 @@ from palm.plugins.dbt.dbt_palm_utils import dbt_env_vars
 def cli(ctx):
     """Removes any artifacts from Snowflake related to the current branch."""
 
-    cmd = "dbt clean && dbt deps && dbt run-operation drop_branch_schemas"
+    cmd = "dbt run-operation drop_branch_schemas && dbt clean && dbt deps"
     env_vars = dbt_env_vars(ctx.obj.palm.branch)
     success, msg = ctx.obj.run_in_docker(cmd, env_vars)
     click.secho(msg, fg="green" if success else "red")
