@@ -8,15 +8,11 @@ from palm.plugins.dbt.dbt_palm_utils import dbt_env_vars
     "--persist", is_flag=True, help="will not drop the test schema at the end"
 )
 @click.option("--select", multiple=True)
-@click.option("--fast", is_flag=True, help="will skip clean/deps/seed")
 @click.pass_context
-def cli(ctx, persist: bool, fast: bool, select: Optional[Tuple] = tuple()):
+def cli(ctx, persist: bool, select: Optional[Tuple] = tuple()):
     """Executes the DBT snapshots."""
 
-    if fast:
-        cmd = "dbt snapshot"
-    else:
-        cmd = "dbt clean && dbt deps && dbt snapshot"
+    cmd = "dbt snapshot"
     if select:
         cmd += f" --select " + " ".join(select)
     if not persist:
